@@ -1,5 +1,8 @@
+#![allow(warnings)]
 //these aren't worth putting behind features
 pub mod errors;
+pub mod prelude;
+pub(crate) mod unwrap; // exported through prelude
 
 //each of these can be enabled/disabled as needed
 #[cfg(feature = "dom")]
